import { createWrapper } from "./wrapper";
export type SuccessStatus = "passed" | "failed" | "unknown";
export type CompletionStatus = "completed" | "incomplete" | "not attempted" | "unknown";
export type MergedStatus = "passed" | "completed" | "failed" | "incomplete" | "browsed" | "not attempted" | "unknown";
export type SCORMStorageType = "1.2" | "2004" | "local";
export type NormalizeRWKeyValue<V extends SCORMStorageType> = {
    successStatus: V extends "1.2" ? MergedStatus : SuccessStatus;
    completeStatus: V extends "1.2" ? MergedStatus : CompletionStatus;
    suspendData: string;
    language: string;
    scoreScaled: number;
    scoreRaw: number;
    scoreMin: number;
    scoreMax: number;
    location: string;
    objectiveList: string[];
    progressMeasure: V extends "2004" ? number : null;
};
export type NormalizeROKeyValue<V extends SCORMStorageType> = {
    studentName: string;
    launchData: string;
    entry: "ab-initio" | "resume" | "";
    interactionsCount: number;
    objectivesCount: number;
};
export type NormalizeWOKeyValue<V extends SCORMStorageType> = {
    sessionTime: string;
    exit: V extends "1.2" ? "time-out" | "suspend" | "logout" | "" : "timeout" | "suspend" | "logout" | "normal" | "";
};
export type NormalizeObjectiveKeyValue<V extends SCORMStorageType> = {
    id: string;
    scoreRaw: number;
    scoreMax: number;
    scoreMin: number;
    successStatus: V extends "1.2" ? MergedStatus : SuccessStatus;
    completionStatus: V extends "1.2" ? MergedStatus : CompletionStatus;
    description: string;
};
export type NormalizeInteractionKeyValue<V extends SCORMStorageType> = {
    id: string;
    weight: number;
    learnerResponse: string;
    result: V extends "1.2" ? "correct" | "wrong" | "unanticipated" | "neutral" | number : "correct" | "incorrect" | "unanticipated" | "neutral" | number;
    objectiveIdList: string[];
    timestamp: number;
    latency: string;
    type: V extends "1.2" ? "true-false" | "choice" | "fill-in" | "matching" | "performance" | "sequencing" | "likert" | "numeric" : "true-false" | "choice" | "fill-in" | "long-fill-in" | "matching" | "performance" | "sequencing" | "likert" | "numeric" | "other";
    description: string;
};
export type FilterScormPresets = "STORYLINE_completed_incomplete" | "STORYLINE_completed_failed" | "STORYLINE_passed_incomplete" | "STORYLINE_passed_failed";
export type FilterScormKeyValue<T extends SCORMStorageType> = ScormKeyFilter<T> & SuccesAndCompleteScormFilter<T>;
export type ScormKeyFilter<T extends SCORMStorageType> = {
    [key in keyof Omit<NormalizeWriteKeyValue<T>, "completeStatus" | "successStatus">]: "blockAll";
};
export type SuccesAndCompleteScormFilter<T extends SCORMStorageType> = {
    [key in keyof Pick<NormalizeWriteKeyValue<T>, "completeStatus" | "successStatus">]: NormalizeWriteKeyValue<T>[key][];
};
export type NormalizeWriteKeyValue<T extends SCORMStorageType> = NormalizeRWKeyValue<T> & NormalizeWOKeyValue<T>;
export type NormalizeReadKeyValue<T extends SCORMStorageType> = NormalizeRWKeyValue<T> & NormalizeROKeyValue<T>;
export type NormalizeKeyValue<T extends SCORMStorageType> = NormalizeReadKeyValue<T> & NormalizeWriteKeyValue<T>;
export type SCORMWrapper = ReturnType<typeof createWrapper>;
