"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = __importDefault(require("chai"));
var chai_spies_1 = __importDefault(require("chai-spies"));
var _1 = require(".");
chai_1.default.use(chai_spies_1.default);
var expect = chai_1.default.expect;
describe("Wrapper", function () {
    var _this = this;
    var storeValue = {};
    var get = chai_1.default.spy(function (key) {
        return storeValue[key];
    });
    var set = chai_1.default.spy(function (key, value) {
        storeValue[key] = value;
        return true;
    });
    var fakepipwerk2004 = {
        debug: {
            isActive: true,
        },
        SCORM: {
            get: get,
            set: set,
            init: function () { return true; },
            quit: function () { return true; },
            save: function () { return true; },
            version: "2004",
        },
        UTILS: {
            trace: function () { return undefined; },
        },
    };
    var fakepipwerk12 = {
        debug: {
            isActive: true,
        },
        SCORM: {
            get: get,
            set: set,
            init: function () { return true; },
            quit: function () { return true; },
            save: function () { return true; },
            version: "1.2",
        },
        UTILS: {
            trace: function () { return undefined; },
        },
    };
    var wrapper2004 = (0, _1.createWrapper)({ baseStorageType: "2004", scormAPIInterface: fakepipwerk2004 });
    var wrapper12 = (0, _1.createWrapper)({ baseStorageType: "1.2", scormAPIInterface: fakepipwerk12 });
    var wrapperWhichStoresInSuspendData = (0, _1.createWrapper)({
        baseStorageType: "2004",
        scormAPIInterface: fakepipwerk2004,
        shouldStoreEverythingInSuspendData: true,
    });
    beforeEach(function () {
        storeValue = {};
    });
    describe("SCORM2004 setter with filters", function () {
        var wrapper2004WithFilter = (0, _1.createWrapper)({
            baseStorageType: "2004",
            scormAPIInterface: fakepipwerk2004,
            filteredScormValues: {
                completeStatus: ["completed", "incomplete"],
                successStatus: ["failed", "passed"],
                scoreRaw: "blockAll",
                scoreScaled: "blockAll",
            },
        });
        it("should block complete status on a setBase action", function () {
            wrapper2004WithFilter.setBaseData("completeStatus", "completed");
            expect(storeValue["cmi.completion_status"]).to.be.undefined;
        });
        it("should block incomplete status on a setBase action", function () {
            wrapper2004WithFilter.setBaseData("completeStatus", "incomplete");
            expect(storeValue["cmi.completion_status"]).to.be.undefined;
        });
        it("should let not_attempted status on a setBase action", function () {
            wrapper2004WithFilter.setBaseData("completeStatus", "not attempted");
            expect(storeValue["cmi.completion_status"]).to.equal("not attempted");
        });
        it("should block passed success status during a setBase action", function () {
            wrapper2004WithFilter.setBaseData("successStatus", "passed");
            expect(storeValue["cmi.success_status"]).to.be.undefined;
        });
        it("should block failed success status during a setBase action", function () {
            wrapper2004WithFilter.setBaseData("successStatus", "failed");
            expect(storeValue["cmi.success_status"]).to.be.undefined;
        });
        it("should let unknown success status during a setBase action", function () {
            wrapper2004WithFilter.setBaseData("successStatus", "unknown");
            expect(storeValue["cmi.success_status"]).to.equal("unknown");
        });
        it("should block complete status on a setBase action", function () {
            wrapper2004WithFilter.setBaseData("completeStatus", "completed");
            expect(storeValue["cmi.completion_status"]).to.be.undefined;
        });
        it("should block incomplete status on a safelySet action", function () {
            return __awaiter(this, void 0, void 0, function () {
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, wrapper2004WithFilter.safelySetCompleteStatus("incomplete")];
                        case 1:
                            _a.sent();
                            expect(storeValue["cmi.completion_status"]).to.be.undefined;
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("should let not_attempted status on a safelySet action", function () {
            return __awaiter(this, void 0, void 0, function () {
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, wrapper2004WithFilter.safelySetCompleteStatus("not attempted")];
                        case 1:
                            _a.sent();
                            expect(storeValue["cmi.completion_status"]).to.equal("not attempted");
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("should block passed success status during a safelySet action", function () {
            return __awaiter(this, void 0, void 0, function () {
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, wrapper2004WithFilter.safelySetSuccessStatus("passed")];
                        case 1:
                            _a.sent();
                            expect(storeValue["cmi.success_status"]).to.be.undefined;
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("should block failed success status during a safelySet action", function () {
            return __awaiter(this, void 0, void 0, function () {
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, wrapper2004WithFilter.safelySetSuccessStatus("failed")];
                        case 1:
                            _a.sent();
                            expect(storeValue["cmi.success_status"]).to.be.undefined;
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("should let unknown success status during a safelySet action", function () {
            return __awaiter(this, void 0, void 0, function () {
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, wrapper2004WithFilter.safelySetSuccessStatus("unknown")];
                        case 1:
                            _a.sent();
                            expect(storeValue["cmi.success_status"]).to.equal("unknown");
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("should block every score update during a setBase action", function () {
            wrapper2004WithFilter.setBaseData("scoreRaw", 1);
            wrapper2004WithFilter.setBaseData("scoreRaw", 10);
            wrapper2004WithFilter.setBaseData("scoreRaw", 20);
            wrapper2004WithFilter.setBaseData("scoreScaled", 0.1);
            wrapper2004WithFilter.setBaseData("scoreScaled", 0.2);
            wrapper2004WithFilter.setBaseData("scoreScaled", 1);
            expect(storeValue["cmi.scoreRaw"]).to.be.undefined;
            expect(storeValue["cmi.scoreScaled"]).to.be.undefined;
        });
    });
    //TODO: To be completed when SCORM_FILTER_PRESETS is properly filled - A.BEDOS 16/02/2022
    describe("SCORM2004 setter with STORYLINE_failed_passed_incomplete preset", function () {
        var wrapper2004WithPreset = (0, _1.createWrapper)({
            baseStorageType: "2004",
            scormAPIInterface: fakepipwerk2004,
            filteredScormValues: "STORYLINE_passed_incomplete",
        });
        it("should allow completed status on a setBase action", function () {
            wrapper2004WithPreset.setBaseData("completeStatus", "completed");
            expect(storeValue["cmi.completion_status"]).to.equal("completed");
        });
        it("should block failed status on a setBase action", function () {
            wrapper2004WithPreset.setBaseData("successStatus", "failed");
            expect(storeValue["cmi.success_status"]).to.be.undefined;
        });
        it("should block failed status on a safelySet action", function () {
            wrapper2004WithPreset.safelySetSuccessStatus("failed");
            expect(storeValue["cmi.success_status"]).to.be.undefined;
        });
        it("should allow passed status on a setBase action", function () {
            wrapper2004WithPreset.setBaseData("successStatus", "passed");
            expect(storeValue["cmi.success_status"]).to.equal("passed");
        });
        it("should allow completed status on a safelySet action", function () {
            return __awaiter(this, void 0, void 0, function () {
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, wrapper2004WithPreset.safelySetCompleteStatus("completed")];
                        case 1:
                            _a.sent();
                            expect(storeValue["cmi.completion_status"]).to.equal("completed");
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("should allow passed status on a safelySet action", function () {
            return __awaiter(this, void 0, void 0, function () {
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, wrapper2004WithPreset.safelySetSuccessStatus("passed")];
                        case 1:
                            _a.sent();
                            expect(storeValue["cmi.success_status"]).to.equal("passed");
                            return [2 /*return*/];
                    }
                });
            });
        });
    });
    describe("SCORM1.2 setter with filters", function () {
        var wrapper12WithFilter = (0, _1.createWrapper)({
            baseStorageType: "1.2",
            scormAPIInterface: fakepipwerk12,
            filteredScormValues: {
                completeStatus: ["completed", "incomplete"],
                successStatus: ["failed", "passed"],
                scoreRaw: "blockAll",
                scoreScaled: "blockAll",
            },
        });
        it("should block complete status on a setBase action", function () {
            wrapper12WithFilter.setBaseData("completeStatus", "completed");
            expect(storeValue["cmi.core.lesson_status"]).to.be.undefined;
        });
        it("should block incomplete status on a setBase action", function () {
            wrapper12WithFilter.setBaseData("completeStatus", "incomplete");
            expect(storeValue["cmi.core.lesson_status"]).to.be.undefined;
        });
        it("should let not_attempted status on a setBase action", function () {
            wrapper12WithFilter.setBaseData("completeStatus", "not attempted");
            expect(storeValue["cmi.core.lesson_status"]).to.equal("not attempted");
        });
        it("should block passed success status during a setBase action", function () {
            wrapper12WithFilter.setBaseData("successStatus", "passed");
            expect(storeValue["cmi.core.lesson_status"]).to.be.undefined;
        });
        it("should block failed success status during a setBase action", function () {
            wrapper12WithFilter.setBaseData("successStatus", "failed");
            expect(storeValue["cmi.core.lesson_status"]).to.be.undefined;
        });
        it("should let unknown success status during a setBase action", function () {
            wrapper12WithFilter.setBaseData("successStatus", "unknown");
            expect(storeValue["cmi.core.lesson_status"]).to.equal("unknown");
        });
        it("should block complete status on a setBase action", function () {
            wrapper12WithFilter.setBaseData("completeStatus", "completed");
            expect(storeValue["cmi.core.lesson_status"]).to.be.undefined;
        });
        it("should block incomplete status on a setBase action", function () {
            wrapper12WithFilter.setBaseData("completeStatus", "incomplete");
            expect(storeValue["cmi.core.lesson_status"]).to.be.undefined;
        });
        it("should let not_attempted status on a setBase action", function () {
            wrapper12WithFilter.setBaseData("completeStatus", "not attempted");
            expect(storeValue["cmi.core.lesson_status"]).to.equal("not attempted");
        });
        it("should block passed success status during a setBase action", function () {
            wrapper12WithFilter.setBaseData("successStatus", "passed");
            expect(storeValue["cmi.core.lesson_status"]).to.be.undefined;
        });
        it("should block failed success status during a setBase action", function () {
            wrapper12WithFilter.setBaseData("successStatus", "failed");
            expect(storeValue["cmi.core.lesson_status"]).to.be.undefined;
        });
        it("should let unknown success status during a setBase action", function () {
            wrapper12WithFilter.setBaseData("successStatus", "unknown");
            expect(storeValue["cmi.core.lesson_status"]).to.equal("unknown");
        });
        it("should block complete status on a safelySet action", function () {
            return __awaiter(this, void 0, void 0, function () {
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, wrapper12WithFilter.safelySetCompleteStatus("completed")];
                        case 1:
                            _a.sent();
                            expect(storeValue["cmi.core.lesson_status"]).to.be.undefined;
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("should block incomplete status on a safelySet action", function () {
            return __awaiter(this, void 0, void 0, function () {
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, wrapper12WithFilter.safelySetCompleteStatus("incomplete")];
                        case 1:
                            _a.sent();
                            expect(storeValue["cmi.core.lesson_status"]).to.be.undefined;
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("should let not_attempted status on a safelySet action", function () {
            return __awaiter(this, void 0, void 0, function () {
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, wrapper12WithFilter.safelySetCompleteStatus("not attempted")];
                        case 1:
                            _a.sent();
                            expect(storeValue["cmi.core.lesson_status"]).to.equal("not attempted");
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("should block passed success status during a safelySet action", function () {
            return __awaiter(this, void 0, void 0, function () {
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, wrapper12WithFilter.safelySetSuccessStatus("passed")];
                        case 1:
                            _a.sent();
                            expect(storeValue["cmi.core.lesson_status"]).to.be.undefined;
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("should block failed success status during a safelySet action", function () {
            return __awaiter(this, void 0, void 0, function () {
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, wrapper12WithFilter.safelySetSuccessStatus("failed")];
                        case 1:
                            _a.sent();
                            expect(storeValue["cmi.core.lesson_status"]).to.be.undefined;
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("should let unknown success status during a safelySet action", function () {
            return __awaiter(this, void 0, void 0, function () {
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, wrapper12WithFilter.safelySetSuccessStatus("unknown")];
                        case 1:
                            _a.sent();
                            expect(storeValue["cmi.core.lesson_status"]).to.equal("unknown");
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("should block every score update during a setBase action", function () {
            wrapper12WithFilter.setBaseData("scoreRaw", 1);
            wrapper12WithFilter.setBaseData("scoreRaw", 10);
            wrapper12WithFilter.setBaseData("scoreRaw", 20);
            wrapper12WithFilter.setBaseData("scoreScaled", 0.1);
            wrapper12WithFilter.setBaseData("scoreScaled", 0.2);
            wrapper12WithFilter.setBaseData("scoreScaled", 1);
            expect(storeValue["cmi.core.score.raw"]).to.be.undefined;
        });
    });
    describe("SCORM misc", function () {
        it("Correctly exposes wrapper created with default SCORM interface", function () {
            var createdWrapper = (0, _1.createWrapper)({ baseStorageType: "2004" });
            expect(createdWrapper).to.have.deep.property("version");
        });
        it("Correctly exposes wrapper created with custom SCORM interface", function () {
            expect(wrapper2004).to.have.deep.property("init");
            expect(wrapper2004).to.have.deep.property("version");
        });
    });
    describe("Getters", function () {
        it("Get base data on SCORM 1.2", function () {
            wrapper12.getBaseData("scoreRaw");
            expect(get).to.have.been.called.with("cmi.core.score.raw");
        });
        it("Get base data on SCORM 2004", function () {
            wrapper2004.getBaseData("scoreRaw");
            expect(get).to.have.been.called.with("cmi.score.raw");
        });
        it("Get interaction data on SCORM 1.2", function () {
            wrapper12.getInteractionData("learnerResponse", 1);
            expect(get).to.have.been.called.with("cmi.interactions.1.student_response");
        });
        it("Get interaction data on SCORM 2004", function () {
            wrapper2004.getInteractionData("learnerResponse", 1);
            expect(get).to.have.been.called.with("cmi.interactions.1.learner_response");
        });
        it("Get objective data on SCORM 1.2", function () {
            wrapper12.getObjectiveData("successStatus", 2);
            expect(get).to.have.been.called.with("cmi.objectives.2.status");
        });
        it("Get objective data on SCORM 2004", function () {
            wrapper2004.getObjectiveData("successStatus", 2);
            expect(get).to.have.been.called.with("cmi.objectives.2.success_status");
        });
    });
    describe("Setters", function () {
        it("Set base data on SCORM 2004", function () {
            wrapper2004.setBaseData("completeStatus", "completed");
            expect(set).to.have.been.called.with("cmi.completion_status", "completed");
        });
        describe("safelySetScore", function () {
            it("should successfully set score if no score is currently set", function () {
                return __awaiter(this, void 0, void 0, function () {
                    var newScore;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                newScore = 10;
                                return [4 /*yield*/, wrapper2004.safelySetScore(newScore)];
                            case 1:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.score.raw", newScore);
                                expect(storeValue["cmi.score.raw"]).to.equal(newScore);
                                return [2 /*return*/];
                        }
                    });
                });
            });
            it("should NOT go below score min", function () {
                return __awaiter(this, void 0, void 0, function () {
                    var scoreMin, targetedScore;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                scoreMin = 50;
                                targetedScore = scoreMin - 10;
                                return [4 /*yield*/, wrapper2004.setBaseData("scoreMin", scoreMin)];
                            case 1:
                                _a.sent();
                                return [4 /*yield*/, wrapper2004.safelySetScore(targetedScore)];
                            case 2:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.score.raw", scoreMin);
                                expect(storeValue["cmi.score.raw"]).to.equal(scoreMin);
                                return [2 /*return*/];
                        }
                    });
                });
            });
            it("should NOT go above score max", function () {
                return __awaiter(this, void 0, void 0, function () {
                    var scoreMax, targetedScore;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                scoreMax = 50;
                                targetedScore = scoreMax + 10;
                                return [4 /*yield*/, wrapper2004.setBaseData("scoreMax", scoreMax)];
                            case 1:
                                _a.sent();
                                return [4 /*yield*/, wrapper2004.safelySetScore(targetedScore)];
                            case 2:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.score.raw", scoreMax);
                                expect(storeValue["cmi.score.raw"]).to.equal(scoreMax);
                                return [2 /*return*/];
                        }
                    });
                });
            });
            it("should NOT go below current score", function () {
                return __awaiter(this, void 0, void 0, function () {
                    var currentScore, targetedScore;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                currentScore = 50;
                                targetedScore = currentScore - 10;
                                return [4 /*yield*/, wrapper2004.setBaseData("scoreRaw", currentScore)];
                            case 1:
                                _a.sent();
                                return [4 /*yield*/, wrapper2004.safelySetScore(targetedScore)];
                            case 2:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.score.raw", currentScore);
                                expect(storeValue["cmi.score.raw"]).to.equal(currentScore);
                                return [2 /*return*/];
                        }
                    });
                });
            });
            it("should replace current score if superior", function () {
                return __awaiter(this, void 0, void 0, function () {
                    var currentScore, targetedScore;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                currentScore = 50;
                                targetedScore = currentScore + 10;
                                return [4 /*yield*/, wrapper2004.setBaseData("scoreRaw", currentScore)];
                            case 1:
                                _a.sent();
                                return [4 /*yield*/, wrapper2004.safelySetScore(targetedScore)];
                            case 2:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.score.raw", targetedScore);
                                expect(storeValue["cmi.score.raw"]).to.equal(targetedScore);
                                return [2 /*return*/];
                        }
                    });
                });
            });
        });
        describe("safelySetScoreScaled", function () {
            it("should successfully set score if no score is currently set", function () {
                return __awaiter(this, void 0, void 0, function () {
                    var newScore;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                newScore = 0.51;
                                return [4 /*yield*/, wrapper2004.safelySetScoreScaled(newScore)];
                            case 1:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.score.scaled", newScore);
                                expect(storeValue["cmi.score.scaled"]).to.equal(newScore);
                                return [2 /*return*/];
                        }
                    });
                });
            });
            it("should NOT go below 0", function () {
                return __awaiter(this, void 0, void 0, function () {
                    var targetedScore;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                targetedScore = -0.1;
                                return [4 /*yield*/, wrapper2004.safelySetScoreScaled(targetedScore)];
                            case 1:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.score.scaled", 0);
                                expect(storeValue["cmi.score.scaled"]).to.equal(0);
                                return [2 /*return*/];
                        }
                    });
                });
            });
            it("should NOT go above 1", function () {
                return __awaiter(this, void 0, void 0, function () {
                    var targetedScore;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                targetedScore = 1.1;
                                return [4 /*yield*/, wrapper2004.safelySetScoreScaled(targetedScore)];
                            case 1:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.score.scaled", 1);
                                expect(storeValue["cmi.score.scaled"]).to.equal(1);
                                return [2 /*return*/];
                        }
                    });
                });
            });
            it("should NOT go below current score", function () {
                return __awaiter(this, void 0, void 0, function () {
                    var currentScore, targetedScore;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                currentScore = 0.5;
                                targetedScore = currentScore - 0.1;
                                return [4 /*yield*/, wrapper2004.setBaseData("scoreScaled", currentScore)];
                            case 1:
                                _a.sent();
                                return [4 /*yield*/, wrapper2004.safelySetScoreScaled(targetedScore)];
                            case 2:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.score.scaled", currentScore);
                                expect(storeValue["cmi.score.scaled"]).to.equal(currentScore);
                                return [2 /*return*/];
                        }
                    });
                });
            });
            it("should replace current score if superior", function () {
                return __awaiter(this, void 0, void 0, function () {
                    var currentScore, targetedScore;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                currentScore = 0.5;
                                targetedScore = currentScore + 0.21;
                                return [4 /*yield*/, wrapper2004.setBaseData("scoreScaled", currentScore)];
                            case 1:
                                _a.sent();
                                return [4 /*yield*/, wrapper2004.safelySetScoreScaled(targetedScore)];
                            case 2:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.score.scaled", targetedScore);
                                expect(storeValue["cmi.score.scaled"]).to.equal(targetedScore);
                                return [2 /*return*/];
                        }
                    });
                });
            });
        });
        describe("safelySetProgressMeasure", function () {
            it("should NOT set progress measure in scorm 1.2 (variable does not exist)", function () {
                return __awaiter(this, void 0, void 0, function () {
                    var recordedProgressMeasure;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0: return [4 /*yield*/, wrapper12.safelySetProgressMeasure(0.1)];
                            case 1:
                                _a.sent();
                                return [4 /*yield*/, wrapper12.getProgressMeasure()];
                            case 2:
                                recordedProgressMeasure = _a.sent();
                                expect(recordedProgressMeasure).to.equal(null);
                                return [2 /*return*/];
                        }
                    });
                });
            });
            it("should simply set progress measure if not previous progress measure exists in scorm 2004", function () {
                return __awaiter(this, void 0, void 0, function () {
                    var recordedProgressMeasure;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0: return [4 /*yield*/, wrapper2004.safelySetProgressMeasure(0.2)];
                            case 1:
                                _a.sent();
                                return [4 /*yield*/, wrapper2004.getProgressMeasure()];
                            case 2:
                                recordedProgressMeasure = _a.sent();
                                expect(recordedProgressMeasure).to.equal(0.2);
                                return [2 /*return*/];
                        }
                    });
                });
            });
            it("should simply set a new progress measure if the previous progress measure is lowerer in scorm 2004", function () {
                return __awaiter(this, void 0, void 0, function () {
                    var recordedProgressMeasure;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                storeValue["cmi.progress_measure"] = 0.2;
                                return [4 /*yield*/, wrapper2004.safelySetProgressMeasure(0.4)];
                            case 1:
                                _a.sent();
                                return [4 /*yield*/, wrapper2004.getProgressMeasure()];
                            case 2:
                                recordedProgressMeasure = _a.sent();
                                expect(recordedProgressMeasure).to.equal(0.4);
                                return [2 /*return*/];
                        }
                    });
                });
            });
            it("should NOT set a new progress measure if the previous progress measure is greater in scorm 2004", function () {
                return __awaiter(this, void 0, void 0, function () {
                    var recordedProgressMeasure;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                storeValue["cmi.progress_measure"] = 0.4;
                                return [4 /*yield*/, wrapper2004.safelySetProgressMeasure(0.2)];
                            case 1:
                                _a.sent();
                                return [4 /*yield*/, wrapper2004.getProgressMeasure()];
                            case 2:
                                recordedProgressMeasure = _a.sent();
                                expect(recordedProgressMeasure).to.equal(0.4);
                                return [2 /*return*/];
                        }
                    });
                });
            });
            it("should NOT set a  progress measure equal to 1 if a greater value is sent in scorm 2004", function () {
                return __awaiter(this, void 0, void 0, function () {
                    var recordedProgressMeasure;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0: return [4 /*yield*/, wrapper2004.safelySetProgressMeasure(4000)];
                            case 1:
                                _a.sent();
                                return [4 /*yield*/, wrapper2004.getProgressMeasure()];
                            case 2:
                                recordedProgressMeasure = _a.sent();
                                expect(recordedProgressMeasure).to.equal(1);
                                return [2 /*return*/];
                        }
                    });
                });
            });
            it("should successfully set status if not previous status exists", function () {
                return __awaiter(this, void 0, void 0, function () {
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0: return [4 /*yield*/, wrapper2004.safelySetSuccessStatus("passed")];
                            case 1:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.success_status", "passed");
                                expect(storeValue["cmi.success_status"]).to.equal("passed");
                                return [2 /*return*/];
                        }
                    });
                });
            });
            it("should allow increase in status", function () {
                return __awaiter(this, void 0, void 0, function () {
                    var initialStatus, nextStatus;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                initialStatus = "unknown";
                                nextStatus = "passed";
                                return [4 /*yield*/, wrapper2004.safelySetSuccessStatus(initialStatus)];
                            case 1:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.success_status", initialStatus);
                                expect(storeValue["cmi.success_status"]).to.equal(initialStatus);
                                return [4 /*yield*/, wrapper2004.safelySetSuccessStatus(nextStatus)];
                            case 2:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.success_status", nextStatus);
                                expect(storeValue["cmi.success_status"]).to.equal(nextStatus);
                                return [2 /*return*/];
                        }
                    });
                });
            });
            it("should allow increase in status", function () {
                return __awaiter(this, void 0, void 0, function () {
                    var initialStatus, nextStatus;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                initialStatus = "passed";
                                nextStatus = "unknown";
                                return [4 /*yield*/, wrapper2004.safelySetSuccessStatus(initialStatus)];
                            case 1:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.success_status", initialStatus);
                                expect(storeValue["cmi.success_status"]).to.equal(initialStatus);
                                return [4 /*yield*/, wrapper2004.safelySetSuccessStatus(nextStatus)];
                            case 2:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.success_status", initialStatus);
                                expect(storeValue["cmi.success_status"]).to.equal(initialStatus);
                                return [2 /*return*/];
                        }
                    });
                });
            });
        });
        describe("safelySetSuccessStatus", function () {
            it("should set status for 1.2 modules with checking", function () {
                return __awaiter(this, void 0, void 0, function () {
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0: return [4 /*yield*/, wrapper12.safelySetSuccessStatus("passed")];
                            case 1:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.core.lesson_status", "passed");
                                expect(storeValue["cmi.core.lesson_status"]).to.equal("passed");
                                return [4 /*yield*/, wrapper12.safelySetSuccessStatus("passed")];
                            case 2:
                                _a.sent();
                                return [4 /*yield*/, wrapper12.safelySetCompleteStatus("completed")];
                            case 3:
                                _a.sent();
                                expect(storeValue["cmi.core.lesson_status"]).to.equal("passed");
                                return [2 /*return*/];
                        }
                    });
                });
            });
            it("should successfully set status if not previous status exists", function () {
                return __awaiter(this, void 0, void 0, function () {
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0: return [4 /*yield*/, wrapper2004.safelySetSuccessStatus("passed")];
                            case 1:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.success_status", "passed");
                                expect(storeValue["cmi.success_status"]).to.equal("passed");
                                return [2 /*return*/];
                        }
                    });
                });
            });
            it("should allow increase in status", function () {
                return __awaiter(this, void 0, void 0, function () {
                    var initialStatus, nextStatus;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                initialStatus = "unknown";
                                nextStatus = "passed";
                                return [4 /*yield*/, wrapper2004.safelySetSuccessStatus(initialStatus)];
                            case 1:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.success_status", initialStatus);
                                expect(storeValue["cmi.success_status"]).to.equal(initialStatus);
                                return [4 /*yield*/, wrapper2004.safelySetSuccessStatus(nextStatus)];
                            case 2:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.success_status", nextStatus);
                                expect(storeValue["cmi.success_status"]).to.equal(nextStatus);
                                return [2 /*return*/];
                        }
                    });
                });
            });
            it("should allow increase in status", function () {
                return __awaiter(this, void 0, void 0, function () {
                    var initialStatus, nextStatus;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                initialStatus = "passed";
                                nextStatus = "unknown";
                                return [4 /*yield*/, wrapper2004.safelySetSuccessStatus(initialStatus)];
                            case 1:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.success_status", initialStatus);
                                expect(storeValue["cmi.success_status"]).to.equal(initialStatus);
                                return [4 /*yield*/, wrapper2004.safelySetSuccessStatus(nextStatus)];
                            case 2:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.success_status", initialStatus);
                                expect(storeValue["cmi.success_status"]).to.equal(initialStatus);
                                return [2 /*return*/];
                        }
                    });
                });
            });
        });
        describe("safelySetCompleteStatus", function () {
            /*it("should set status for 1.2 modules without checking", async function () {
              await wrapper12.safelySetCompleteStatus("completed");
      
              expect(set).to.have.been.called.with("cmi.core.lesson_status", "completed");
              expect(storeValue["cmi.core.lesson_status"]).to.equal("completed");
      
              await wrapper12.safelySetCompleteStatus("unknown");
      
              expect(set).to.have.been.called.with("cmi.core.lesson_status", "not attempted");
              expect(storeValue["cmi.core.lesson_status"]).to.equal("not attempted");
            });*/
            it("should successfully set status if not previous status exists", function () {
                return __awaiter(this, void 0, void 0, function () {
                    var nextStatus;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                nextStatus = "completed";
                                return [4 /*yield*/, wrapper2004.safelySetCompleteStatus(nextStatus)];
                            case 1:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.completion_status", nextStatus);
                                expect(storeValue["cmi.completion_status"]).to.equal(nextStatus);
                                return [2 /*return*/];
                        }
                    });
                });
            });
            it("should allow increase in status", function () {
                return __awaiter(this, void 0, void 0, function () {
                    var initialStatus, nextStatus;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                initialStatus = "unknown";
                                nextStatus = "completed";
                                return [4 /*yield*/, wrapper2004.safelySetCompleteStatus(initialStatus)];
                            case 1:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.completion_status", initialStatus);
                                expect(storeValue["cmi.completion_status"]).to.equal(initialStatus);
                                return [4 /*yield*/, wrapper2004.safelySetCompleteStatus(nextStatus)];
                            case 2:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.completion_status", nextStatus);
                                expect(storeValue["cmi.completion_status"]).to.equal(nextStatus);
                                return [2 /*return*/];
                        }
                    });
                });
            });
            it("should allow increase in status", function () {
                return __awaiter(this, void 0, void 0, function () {
                    var initialStatus, nextStatus;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                initialStatus = "completed";
                                nextStatus = "unknown";
                                return [4 /*yield*/, wrapper2004.safelySetCompleteStatus(initialStatus)];
                            case 1:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.completion_status", initialStatus);
                                expect(storeValue["cmi.completion_status"]).to.equal(initialStatus);
                                return [4 /*yield*/, wrapper2004.safelySetCompleteStatus(nextStatus)];
                            case 2:
                                _a.sent();
                                expect(set).to.have.been.called.with("cmi.completion_status", initialStatus);
                                expect(storeValue["cmi.completion_status"]).to.equal(initialStatus);
                                return [2 /*return*/];
                        }
                    });
                });
            });
        });
    });
    describe("Store in suspend data options", function () {
        it("Set interaction data", function () {
            return __awaiter(this, void 0, void 0, function () {
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, wrapperWhichStoresInSuspendData.setInteractionData("id", 0, "lalala")];
                        case 1:
                            _a.sent();
                            return [4 /*yield*/, wrapperWhichStoresInSuspendData.setInteractionData("id", 1, "lololo")];
                        case 2:
                            _a.sent();
                            expect(set).to.have.been.called.with("cmi.suspend_data", JSON.stringify({ objectiveList: [], interactionList: [{ id: "lalala" }, { id: "lololo" }] }));
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("Get interaction data", function () {
            wrapperWhichStoresInSuspendData.getInteractionData("id", 0);
            expect(get).to.have.been.called.with("cmi.suspend_data");
        });
        it("Set objective data", function () {
            return __awaiter(this, void 0, void 0, function () {
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, wrapperWhichStoresInSuspendData.setObjectiveData("id", 0, "lalala")];
                        case 1:
                            _a.sent();
                            return [4 /*yield*/, wrapperWhichStoresInSuspendData.setObjectiveData("id", 1, "lololo")];
                        case 2:
                            _a.sent();
                            expect(set).to.have.been.called.with("cmi.suspend_data");
                            return [2 /*return*/];
                    }
                });
            });
        });
    });
    describe("Check if LMS number value are transmitted with real number in Scorm 2004", function () {
        it("get the LMS stored score raw value and send a real number", function () {
            return __awaiter(this, void 0, void 0, function () {
                var gettedScore;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, wrapper2004.safelySetScore(10)];
                        case 1:
                            _a.sent();
                            expect(set).to.have.been.called.with("cmi.score.raw", 10);
                            return [4 /*yield*/, wrapper2004.getGlobalScoreRaw()];
                        case 2:
                            gettedScore = _a.sent();
                            expect(storeValue["cmi.score.raw"]).to.equal(gettedScore);
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("get the LMS stored score raw null value and send a null value", function () {
            return __awaiter(this, void 0, void 0, function () {
                var gettedScore;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            storeValue["cmi.score.raw"] = null;
                            return [4 /*yield*/, wrapper2004.getGlobalScoreRaw()];
                        case 1:
                            gettedScore = _a.sent();
                            expect(gettedScore).to.equal(null);
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("get the LMS stored score raw unreadable string value and send a null value", function () {
            return __awaiter(this, void 0, void 0, function () {
                var gettedScore;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            storeValue["cmi.score.raw"] = "not a number";
                            return [4 /*yield*/, wrapper2004.getGlobalScoreRaw()];
                        case 1:
                            gettedScore = _a.sent();
                            expect(gettedScore).to.equal(null);
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("get the LMS stored score raw number as a string value and send a real number", function () {
            return __awaiter(this, void 0, void 0, function () {
                var gettedScore;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            storeValue["cmi.score.raw"] = "30";
                            return [4 /*yield*/, wrapper2004.getGlobalScoreRaw()];
                        case 1:
                            gettedScore = _a.sent();
                            expect(gettedScore).to.equal(30);
                            return [2 /*return*/];
                    }
                });
            });
        });
        //SCALED
        it("get the LMS stored score scaled value and send a real number", function () {
            return __awaiter(this, void 0, void 0, function () {
                var gettedScore;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, wrapper2004.safelySetScoreScaled(0.1)];
                        case 1:
                            _a.sent();
                            expect(set).to.have.been.called.with("cmi.score.scaled", 0.1);
                            return [4 /*yield*/, wrapper2004.getGlobalScoreScaled()];
                        case 2:
                            gettedScore = _a.sent();
                            expect(storeValue["cmi.score.scaled"]).to.equal(gettedScore);
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("get the LMS stored score scaled null value and send a null value", function () {
            return __awaiter(this, void 0, void 0, function () {
                var gettedScore;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            storeValue["cmi.score.scaled"] = null;
                            return [4 /*yield*/, wrapper2004.getGlobalScoreScaled()];
                        case 1:
                            gettedScore = _a.sent();
                            expect(gettedScore).to.equal(null);
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("get the LMS stored score scaled unreadable string value and send a null value", function () {
            return __awaiter(this, void 0, void 0, function () {
                var gettedScore;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            storeValue["cmi.score.scaled"] = "not a number";
                            return [4 /*yield*/, wrapper2004.getGlobalScoreScaled()];
                        case 1:
                            gettedScore = _a.sent();
                            expect(gettedScore).to.equal(null);
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("get the LMS stored score scaled number as a string value and send a real number", function () {
            return __awaiter(this, void 0, void 0, function () {
                var gettedScore;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            storeValue["cmi.score.scaled"] = "0.8";
                            return [4 /*yield*/, wrapper2004.getGlobalScoreScaled()];
                        case 1:
                            gettedScore = _a.sent();
                            expect(gettedScore).to.equal(0.8);
                            return [2 /*return*/];
                    }
                });
            });
        });
        //PROGRESS
        it("get the LMS stored progress measure with null value and send a null value", function () {
            return __awaiter(this, void 0, void 0, function () {
                var gettedProgressMeasure;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            storeValue["cmi.progress_measure"] = null;
                            return [4 /*yield*/, wrapper2004.getProgressMeasure()];
                        case 1:
                            gettedProgressMeasure = _a.sent();
                            expect(gettedProgressMeasure).to.equal(null);
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("get the LMS stored progress measure unreadable string value and send a null value", function () {
            return __awaiter(this, void 0, void 0, function () {
                var gettedProgressMeasure;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            storeValue["cmi.progress_measure"] = "not a number";
                            return [4 /*yield*/, wrapper2004.getProgressMeasure()];
                        case 1:
                            gettedProgressMeasure = _a.sent();
                            expect(gettedProgressMeasure).to.equal(null);
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("get the LMS stored progress measure number as a string value and send a real number", function () {
            return __awaiter(this, void 0, void 0, function () {
                var gettedProgressMeasure;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            storeValue["cmi.progress_measure"] = "0.8";
                            return [4 /*yield*/, wrapper2004.getProgressMeasure()];
                        case 1:
                            gettedProgressMeasure = _a.sent();
                            expect(gettedProgressMeasure).to.equal(0.8);
                            return [2 /*return*/];
                    }
                });
            });
        });
    });
    describe("Check if LMS number value are transmitted with real number in Scorm 1.2", function () {
        it("get the LMS stored score raw value and send a real number", function () {
            return __awaiter(this, void 0, void 0, function () {
                var gettedScore;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, wrapper12.safelySetScore(10)];
                        case 1:
                            _a.sent();
                            return [4 /*yield*/, wrapper12.getGlobalScoreRaw()];
                        case 2:
                            gettedScore = _a.sent();
                            expect(storeValue["cmi.core.score.raw"]).to.equal(gettedScore);
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("get the LMS stored score raw null value and send a null data", function () {
            return __awaiter(this, void 0, void 0, function () {
                var gettedScore;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            storeValue["cmi.core.score.raw"] = null;
                            return [4 /*yield*/, wrapper12.getGlobalScoreRaw()];
                        case 1:
                            gettedScore = _a.sent();
                            expect(gettedScore).to.equal(null);
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("get the LMS stored score raw unreadable string value and send a null data", function () {
            return __awaiter(this, void 0, void 0, function () {
                var gettedScore;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            storeValue["cmi.core.score.raw"] = "not a number";
                            return [4 /*yield*/, wrapper12.getGlobalScoreRaw()];
                        case 1:
                            gettedScore = _a.sent();
                            expect(gettedScore).to.equal(null);
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("get the LMS stored score raw number as a string value and send a real number", function () {
            return __awaiter(this, void 0, void 0, function () {
                var gettedScore;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            storeValue["cmi.core.score.raw"] = "30";
                            return [4 /*yield*/, wrapper12.getGlobalScoreRaw()];
                        case 1:
                            gettedScore = _a.sent();
                            expect(gettedScore).to.equal(30);
                            return [2 /*return*/];
                    }
                });
            });
        });
        //SCALED
        it("get the LMS stored score scaled value and send a real number", function () {
            return __awaiter(this, void 0, void 0, function () {
                var gettedScore;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, wrapper12.safelySetScoreScaled(0.1)];
                        case 1:
                            _a.sent();
                            return [4 /*yield*/, wrapper12.getGlobalScoreScaled()];
                        case 2:
                            gettedScore = _a.sent();
                            expect(gettedScore).to.equal(null);
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("get the LMS stored score scaled null value and send a null data", function () {
            return __awaiter(this, void 0, void 0, function () {
                var gettedScore;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            storeValue["cmi.core.score.raw"] = null;
                            return [4 /*yield*/, wrapper12.getGlobalScoreScaled()];
                        case 1:
                            gettedScore = _a.sent();
                            expect(gettedScore).to.equal(null);
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("get the LMS stored score scaled unreadable string value and send a null data", function () {
            return __awaiter(this, void 0, void 0, function () {
                var gettedScore;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            storeValue["cmi.core.score.raw"] = "not a number";
                            return [4 /*yield*/, wrapper12.getGlobalScoreScaled()];
                        case 1:
                            gettedScore = _a.sent();
                            expect(gettedScore).to.equal(null);
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("get the LMS stored score scaled number as a string value and send a real number", function () {
            return __awaiter(this, void 0, void 0, function () {
                var gettedScore;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            storeValue["cmi.core.score.raw"] = "0.8";
                            return [4 /*yield*/, wrapper12.getGlobalScoreScaled()];
                        case 1:
                            gettedScore = _a.sent();
                            expect(gettedScore).to.equal(null);
                            return [2 /*return*/];
                    }
                });
            });
        });
        //PROGRESS
        it("get the LMS stored progress measure with null value and send a null value", function () {
            return __awaiter(this, void 0, void 0, function () {
                var gettedProgressMeasure;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            storeValue["cmi.progress_measure"] = null;
                            return [4 /*yield*/, wrapper12.getProgressMeasure()];
                        case 1:
                            gettedProgressMeasure = _a.sent();
                            expect(gettedProgressMeasure).to.equal(null);
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("get the LMS stored progress measure string value and send a null value", function () {
            return __awaiter(this, void 0, void 0, function () {
                var gettedProgressMeasure;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            storeValue["cmi.progress_measure"] = "not a number";
                            return [4 /*yield*/, wrapper12.getProgressMeasure()];
                        case 1:
                            gettedProgressMeasure = _a.sent();
                            expect(gettedProgressMeasure).to.equal(null);
                            return [2 /*return*/];
                    }
                });
            });
        });
        it("get the LMS stored progress measure number as a string value and send a null value", function () {
            return __awaiter(this, void 0, void 0, function () {
                var gettedProgressMeasure;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            storeValue["cmi.progress_measure"] = "0.8";
                            return [4 /*yield*/, wrapper12.getProgressMeasure()];
                        case 1:
                            gettedProgressMeasure = _a.sent();
                            expect(gettedProgressMeasure).to.equal(null);
                            return [2 /*return*/];
                    }
                });
            });
        });
    });
    describe("Debounced save", function () {
        var wait = function (delayInMs) { return new Promise(function (res) { return setTimeout(function () { return res(undefined); }, delayInMs); }); };
        var sandbox = chai_1.default.spy.sandbox();
        beforeEach(function () {
            sandbox.on(fakepipwerk2004.SCORM, "save");
        });
        afterEach(function () {
            sandbox.restore(); // restores original methods on `array`
        });
        it("should not debounce if option is not set", function () { return __awaiter(_this, void 0, void 0, function () {
            var wrapper2004;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        wrapper2004 = (0, _1.createWrapper)({
                            baseStorageType: "2004",
                            scormAPIInterface: fakepipwerk2004,
                        });
                        return [4 /*yield*/, Promise.all([
                                wrapper2004.setBaseData("completeStatus", "completed"),
                                wrapper2004.setBaseData("completeStatus", "completed"),
                                wrapper2004.setBaseData("completeStatus", "completed"),
                            ])];
                    case 1:
                        _a.sent();
                        expect(fakepipwerk2004.SCORM.save).to.have.been.called.exactly(3);
                        return [2 /*return*/];
                }
            });
        }); });
        it("should not debounce if option is set to false", function () { return __awaiter(_this, void 0, void 0, function () {
            var wrapper2004;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        wrapper2004 = (0, _1.createWrapper)({
                            baseStorageType: "2004",
                            scormAPIInterface: fakepipwerk2004,
                            debounceCommits: { isActive: false, delayInMs: 0 },
                        });
                        return [4 /*yield*/, Promise.all([
                                wrapper2004.setBaseData("completeStatus", "completed"),
                                wrapper2004.setBaseData("completeStatus", "completed"),
                                wrapper2004.setBaseData("completeStatus", "completed"),
                            ])];
                    case 1:
                        _a.sent();
                        expect(fakepipwerk2004.SCORM.save).to.have.been.called.exactly(3);
                        return [2 /*return*/];
                }
            });
        }); });
        it("should debounce save in case of multiple commits", function () { return __awaiter(_this, void 0, void 0, function () {
            var delayInMs, wrapper2004;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        delayInMs = 20;
                        wrapper2004 = (0, _1.createWrapper)({
                            baseStorageType: "2004",
                            scormAPIInterface: fakepipwerk2004,
                            debounceCommits: { isActive: true, delayInMs: delayInMs },
                        });
                        return [4 /*yield*/, Promise.all([
                                wrapper2004.setBaseData("completeStatus", "completed"),
                                wrapper2004.setBaseData("completeStatus", "completed"),
                                wrapper2004.setBaseData("completeStatus", "completed"),
                            ])];
                    case 1:
                        _a.sent();
                        return [4 /*yield*/, wait(delayInMs + 10)];
                    case 2:
                        _a.sent();
                        expect(fakepipwerk2004.SCORM.save).to.have.been.called.once;
                        return [2 /*return*/];
                }
            });
        }); });
    });
});
//# sourceMappingURL=wrapper.test.js.map